@@ -2,7 +2,7 @@
  * debtags - Implement package tags support for Debian
  *
  * Copyright (C) 2007  Enrico Zini <enrico@debian.org>
- * Copyright (C) 2007  Miriam Ruiz <little_miry@yahoo.es>
+ * Copyright (C) 2007, 2008  Miriam Ruiz <little_miry@yahoo.es>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,16 +91,15 @@ using namespace std;
 using namespace ept;
 using namespace ept::debtags;
 using namespace ept::apt;
-using namespace ept::textsearch;
 
-char* tagString(const Tag& tag)
+char* tagString(const std::string& tag)
 {
 	static map<string, char*> table;
-	map<string, char*>::iterator i = table.find(tag.fullname());
+	map<string, char*>::iterator i = table.find(tag);
 	if (i == table.end())
 	{
 		pair< map<string, char*>::iterator, bool > tmp =
-			table.insert(make_pair(tag.fullname(), strdup(tag.fullname().c_str())));
+			table.insert(make_pair(tag, strdup(tag.c_str())));
 		i = tmp.first;
 	}
 	return i->second;
@@ -128,18 +127,18 @@ void printResults(Engine& engine)
 		cerr << "PKG " << pkg.package() << " - " << pkg.shortDescription() << endl;
 	}
 
-	const set<Tag>& ttags = engine.types();
-	for (set<Tag>::const_iterator i = ttags.begin();
+	const set<string>& ttags = engine.types();
+	for (set<string>::const_iterator i = ttags.begin();
 			i != ttags.end(); ++i)
 	{
-		cerr << "TTAG " << i->fullname() << endl;
+		cerr << "TTAG " << *i << endl;
 	}
 
-	const set<Tag>& ftags = engine.interfaces();
-	for (set<Tag>::const_iterator i = ftags.begin();
+	const set<string>& ftags = engine.interfaces();
+	for (set<string>::const_iterator i = ftags.begin();
 			i != ftags.end(); ++i)
 	{
-		cerr << "ITAG " << i->fullname() << endl;
+		cerr << "ITAG " << *i << endl;
 	}
 }
 
@@ -186,32 +185,34 @@ static void UpdateUILists(GamesUI& ui)
 
 	// FIXME: there are better ways to remember the previous item
 	
-	const set<Tag> types = engine.types();
+	const set<string> types = engine.types();
 	int newIdx = 0;
-	for (set<Tag>::const_iterator i = types.begin();
+	for (set<string>::const_iterator i = types.begin();
 			i != types.end(); ++i)
 	{
-		int idx = ui.TypeSelection->add(gettext(i->shortDescription().c_str()),
+		const voc::TagData* td = engine.voc().tagData(*i);
+		if (!td) continue;
+		int idx = ui.TypeSelection->add(gettext(td->shortDescription().c_str()),
 							0, NULL, tagString(*i), FL_NORMAL_LABEL);
-		if (i->fullname() == oldType)
+		if (*i == oldType)
 			newIdx = idx;
 	}
 	ui.TypeSelection->value(newIdx);
 	
-	const set<Tag> ifaces = engine.interfaces();
+	const set<std::string> ifaces = engine.interfaces();
 	newIdx = 0;
-	for (set<Tag>::const_iterator i = ifaces.begin();
+	for (set<std::string>::const_iterator i = ifaces.begin();
 			i != ifaces.end(); ++i)
 	{
-		int idx = ui.InterfaceSelection->add(gettext(i->shortDescription().c_str()),
+		const voc::TagData* td = engine.voc().tagData(*i);
+		if (!td) continue;
+		int idx = ui.InterfaceSelection->add(gettext(td->shortDescription().c_str()),
 							0, NULL, tagString(*i), FL_NORMAL_LABEL);
-		if (i->fullname() == oldIface)
+		if (*i == oldIface)
 			newIdx = idx;
 	}
 	ui.InterfaceSelection->value(newIdx);
 
-	PackageFilter filter;
-
 	const std::vector<Result> res = engine.results();
 	for (vector<Result>::const_iterator i = res.begin();
 			i != res.end(); ++i)
@@ -225,8 +226,8 @@ static void UpdateUILists(GamesUI& ui)
 
 		Fl_Color bk(FL_WHITE);
 		Fl_Color fr(FL_BLACK);
-		set<Tag> tags = ui.engine->debtags().getTagsOfItem((const char *)rec.package().c_str());
-		switch (filter.TagsValue(tags))
+		set<std::string> tags = ui.engine->debtags().getTagsOfItem((const char *)rec.package().c_str());
+		switch (pkgfilter.TagsValue(tags))
 		{
 			case PackageFilter::Green:
 				fr = FL_BLACK; bk = FL_GREEN; break;
@@ -267,8 +268,7 @@ static void CallBackTypeSelection(Fl_Choice* choice, void *data)
 	//printf("CallBackTypeSelection\n");
 	//fflush(stdout);
 	GamesUI& ui = *static_cast<GamesUI*>(data);
-	Tag tag = ui.engine->voc().tagByName(ReadFlChoice(*choice));
-	ui.engine->setTypeFilter(tag);
+	ui.engine->setTypeFilter(ReadFlChoice(*choice));
 	UpdateUILists(ui);
 }
 
@@ -277,8 +277,7 @@ static void CallBackInterfaceSelection(Fl_Choice* choice, void *data)
 	//printf("CallBackInterfaceSelection\n");
 	//fflush(stdout);
 	GamesUI& ui = *static_cast<GamesUI*>(data);
-	Tag tag = ui.engine->voc().tagByName(ReadFlChoice(*choice));
-	ui.engine->setInterfaceFilter(tag);
+	ui.engine->setInterfaceFilter(ReadFlChoice(*choice));
 	UpdateUILists(ui);
 }
 
@@ -331,6 +330,7 @@ static void OnResultsBrowserClick(Fl_Browser*, void *data)
 }
 #endif
 
+#ifndef UNIT_TEST
 int main(int argc, const char* argv[])
 {
 #ifdef USE_GETTEXT
@@ -506,6 +506,7 @@ int main(int argc, const char* argv[])
 	}
 
 }
+#endif
 
 #include <ept/debtags/debtags.tcc>
 
