@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007  Miriam Ruiz <little_miry@yahoo.es>
+ * Copyright (C) 2007, 2008  Miriam Ruiz <little_miry@yahoo.es>
  *
  * VersatileBrowser uses ColResizeBrowser, written by Greg Ercolano
  * ColResizeBrowser (C) Greg Ercolano <erco@seriss.com>
@@ -35,13 +35,14 @@
 #include "pkgbrowser.h"
 #include "ui.h"
 #include "common.h"
-#include "filter.h"
 #include "aux.h"
 
 #include "Environment.h"
 #include "GamesOptions.h"
 #include "Engine.h"
 
+#include "filter.h"
+
 #include <ept/apt/packagerecord.h>
 
 #include <stdio.h>
@@ -65,10 +66,8 @@ using namespace std;
 using namespace ept;
 using namespace ept::debtags;
 using namespace ept::apt;
-using namespace ept::textsearch;
 
 static const char legalchars[] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz@_?+-,.~/%&=:*#";
-#define SIZE_URI 256
 
 PackageBrowser::PackageBrowser(int x, int y, int w, int h, const char *l)
 	: VersatileBrowser(x, y, w, h, l), num_bar_images(2)
@@ -105,16 +104,23 @@ static void text2html(const std::string &in_text, std::string &out_html)
 		if (!strncasecmp("http:", src, 5) || !strncasecmp("mailto:", src, 7) ||
 			!strncasecmp("ftp:", src, 4) || !strncasecmp("https:", src, 6))
 		{
-			char uri[SIZE_URI];
-			int i;
-			for (i = 0; *src && (strchr(legalchars, *src) || (*src & 128)) && i < SIZE_URI-1; i++)
-				uri[i] = *src++;
-			if (strchr(".?!", uri[i-1])) { --i; --src; } // Probably the end of a sentence
-			uri[i] = 0;
+			std::string uri, uri_text;
+			for (; *src && (strchr(legalchars, *src) || (*src & 128)); src++)
+			{
+				uri += *src;
+				uri_text += *src;
+				if (*src == '/')
+					uri_text += "<wbr>";
+			}
+			if (strchr(".?!", src[-1])) {  // Probably the end of a sentence
+				--src;
+				uri.resize(uri.size() - 1);
+				uri_text.resize(uri_text.size() - 1);
+			}
 			out_html += "<a href=\"";
 			out_html += uri;
 			out_html += "\">";
-			out_html += uri;
+			out_html += uri_text;
 			out_html += "</a>";
 		}
 		else if (!strncasecmp(" .\n", src, 3))
@@ -221,18 +227,21 @@ void PackageBrowser::item_select(void *p, int s)
 			ui->DebTagsBrowser->column_widths(widths);
 			ui->DebTagsBrowser->add(_("@B12@C7@b@.FACET\t@B12@C7@b@.TAG"));
 
-			set<Tag> tags = ui->engine->debtags().getTagsOfItem((const char *)data);
-			PackageFilter filter;
+			set<std::string> tags = ui->engine->debtags().getTagsOfItem((const char *)data);
 			char *tag_txt = new char[512];
-			for (set<Tag>::const_iterator i = tags.begin(); i != tags.end(); ++i)
+			for (set<std::string>::const_iterator i = tags.begin(); i != tags.end(); ++i)
 			{
+				const voc::FacetData* fd = ui->engine->voc().facetData(voc::getfacet(*i));
+				const voc::TagData* td = ui->engine->voc().tagData(*i);
+				if (!fd || !td) continue;
+
 				// Available Colors: FL_BLACK, FL_BLUE, FL_CYAN, FL_DARK_BLUE,
 				// FL_DARK_CYAN, FL_DARK_GREEN FL_DARK_MAGENTA, FL_DARK_RED,
 				// FL_DARK_YELLOW, FL_GREEN, FL_MAGENTA, FL_RED, FL_WHITE, FL_YELLOW
 
 				Fl_Color bk(FL_WHITE);
 				Fl_Color fr(FL_BLACK);
-				switch (filter.TagValue(*i))
+				switch (pkgfilter.TagValue(*i))
 				{
 					case PackageFilter::Green:
 						fr = FL_BLACK; bk = FL_GREEN; break;
@@ -247,9 +256,9 @@ void PackageBrowser::item_select(void *p, int s)
 				}
 				snprintf(tag_txt, 512, "@B%d@C%d@.%s\t@B%d@C%d@.%s",
 					bk, fr,
-					gettext(i->facet().shortDescription().c_str()),
+					gettext(fd->shortDescription().c_str()),
 					bk, fr,
-					gettext(i->shortDescription().c_str())
+					gettext(td->shortDescription().c_str())
 				);
 				ui->DebTagsBrowser->add(tag_txt);
 			}
